==> activity-center-biz-1.2.9.8.transfer-20161118.085627-1-sources.jar: cn/com/duiba/activity/center/biz/entity/gamecenter/GameCenterResourceLocationEntity.java <==
/**
 * Project Name:activity-center-biz File Name:GameCenterResourceLocationEntity.java Package
 * Name:cn.com.duiba.activity.center.biz.entity.gamecenter Date:2016年10月20日上午10:21:00 Copyright (c) 2016, duiba.com.cn
 * All Rights Reserved.
 */

package cn.com.duiba.activity.center.biz.entity.gamecenter;

import java.io.Serializable;
import java.util.Date;

import cn.com.duiba.activity.center.common.dto.BaseEntity;

/**
 * ClassName:GameCenterResourceLocationEntity <br/>
 * Function: TODO ADD FUNCTION. <br/>
 * Reason: TODO ADD REASON. <br/>
 * Date: 2016年10月20日 上午10:21:00 <br/>
 *
 * @author zhuzhiyong
 * @version
 * @see
 * @since JDK 1.6
 */
public class GameCenterResourceLocationEntity extends BaseEntity implements Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = -3881643581542264822L;

    /** 逻辑主键. */
    private Long              id;

    /** 资源位名称. */
    private String            name;

    /** 展示名. */
    private String            title;

    /** 资源位描述. */
    private String            description;

    /** 最大资源数限制. */
    private Integer           maxLimit;

    /** 最小资源数限制. */
    private Integer           minLimit;

    /** 资源位. */
    private Integer           payload;

    /** 状态. */
    private Byte              status;

    /** The gmt create. */
    private Date              gmtCreate;

    /** The gmt modified. */
    private Date              gmtModified;

    /**
     * id.
     *
     * @return the id
     */
    public Long getId() {
        return id;
    }

    /**
     * id.
     *
     * @param id the id to set
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * name.
     *
     * @return the name
     */
    public String getName() {
        return name;
    }

    /**
     * name.
     *
     * @param name the name to set
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * title.
     *
     * @return the title
     */
    public String getTitle() {
        return title;
    }

    /**
     * title.
     *
     * @param title the title to set
     */
    public void setTitle(String title) {
        this.title = title;
    }

    /**
     * description.
     *
     * @return the description
     */
    public String getDescription() {
        return description;
    }

    /**
     * description.
     *
     * @param description the description to set
     */
    public void setDescription(String description) {
        this.description = description;
    }

    /**
     * maxLimit.
     *
     * @return the maxLimit
     */
    public Integer getMaxLimit() {
        return maxLimit;
    }

    /**
     * maxLimit.
     *
     * @param maxLimit the maxLimit to set
     */
    public void setMaxLimit(Integer maxLimit) {
        this.maxLimit = maxLimit;
    }

    /**
     * minLimit.
     *
     * @return the minLimit
     */
    public Integer getMinLimit() {
        return minLimit;
    }

    /**
     * minLimit.
     *
     * @param minLimit the minLimit to set
     */
    public void setMinLimit(Integer minLimit) {
        this.minLimit = minLimit;
    }

    /**
     * payload.
     *
     * @return the payload
     */
    public Integer getPayload() {
        return payload;
    }

    /**
     * payload.
     *
     * @param payload the payload to set
     */
    public void setPayload(Integer payload) {
        this.payload = payload;
    }

    /**
     * status.
     *
     * @return the status
     */
    public Byte getStatus() {
        return status;
    }

    /**
     * status.
     *
     * @param status the status to set
     */
    public void setStatus(Byte status) {
        this.status = status;
    }

    /**
     * gmtCreate.
     *
     * @return the gmtCreate
     */
    public Date getGmtCreate() {
        return gmtCreate;
    }

    /**
     * gmtCreate.
     *
     * @param gmtCreate the gmtCreate to set
     */
    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    /**
     * gmtModified.
     *
     * @return the gmtModified
     */
    public Date getGmtModified() {
        return gmtModified;
    }

    /**
     * gmtModified.
     *
     * @param gmtModified the gmtModified to set
     */
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    /**
     * TODO 简单描述该方法的实现功能（可选）.
     * 
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder();
        builder.append("GameCenterResourceLocationEntity [id=");
        builder.append(id);
        builder.append(", name=");
        builder.append(name);
        builder.append(", title=");
        builder.append(title);
        builder.append(", description=");
        builder.append(description);
        builder.append(", maxLimit=");
        builder.append(maxLimit);
        builder.append(", minLimit=");
        builder.append(minLimit);
        builder.append(", payload=");
        builder.append(payload);
        builder.append(", status=");
        builder.append(status);
        builder.append(", gmtCreate=");
        builder.append(gmtCreate);
        builder.append(", gmtModified=");
        builder.append(gmtModified);
        builder.append("]");
        return builder.toString();
    }

}

==> activity-center-biz-1.2.9.11.transfer-20161118.093154-1-sources.jar: cn/com/duiba/activity/center/biz/entity/gamecenter/GameCenterResourceLocationEntity.java <==
/**
 * Project Name:activity-center-biz File Name:GameCenterResourceLocationEntity.java Package
 * Name:cn.com.duiba.activity.center.biz.entity.gamecenter Date:2016年10月20日上午10:21:00 Copyright (c) 2016, duiba.com.cn
 * All Rights Reserved.
 */

package cn.com.duiba.activity.center.biz.entity.gamecenter;

import java.io.Serializable;
import java.util.Date;

import cn.com.duiba.activity.center.common.dto.BaseEntity;

/**
 * ClassName:GameCenterResourceLocationEntity <br/>
 * Function: TODO ADD FUNCTION. <br/>
 * Reason: TODO ADD REASON. <br/>
 * Date: 2016年10月20日 上午10:21:00 <br/>
 *
 * @author zhuzhiyong
 * @version
 * @see
 * @since JDK 1.6
 */
public class GameCenterResourceLocationEntity extends BaseEntity implements Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = -3881643581542264822L;

    /** 逻辑主键. */
    private Long              id;

    /** 资源位名称. */
    private String            name;

    /** 展示名. */
    private String            title;

    /** 资源位描述. */
    private String            description;

    /** 最大资源数限制. */
    private Integer           maxLimit;

    /** 最小资源数限制. */
    private Integer           minLimit;

    /** 资源位. */
    private Integer           payload;

    /** 状态. */
    private Byte              status;

    /** The gmt create. */
    private Date              gmtCreate;

    /** The gmt modified. */
    private Date              gmtModified;

    /**
     * id.
     *
     * @return the id
     */
    public Long getId() {
        return id;
    }

    /**
     * id.
     *
     * @param id the id to set
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * name.
     *
     * @return the name
     */
    public String getName() {
        return name;
    }

    /**
     * name.
     *
     * @param name the name to set
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * title.
     *
     * @return the title
     */
    public String getTitle() {
        return title;
    }

    /**
     * title.
     *
     * @param title the title to set
     */
    public void setTitle(String title) {
        this.title = title;
    }

    /**
     * description.
     *
     * @return the description
     */
    public String getDescription() {
        return description;
    }

    /**
     * description.
     *
     * @param description the description to set
     */
    public void setDescription(String description) {
        this.description = description;
    }

    /**
     * maxLimit.
     *
     * @return the maxLimit
     */
    public Integer getMaxLimit() {
        return maxLimit;
    }

    /**
     * maxLimit.
     *
     * @param maxLimit the maxLimit to set
     */
    public void setMaxLimit(Integer maxLimit) {
        this.maxLimit = maxLimit;
    }

    /**
     * minLimit.
     *
     * @return the minLimit
     */
    public Integer getMinLimit() {
        return minLimit;
    }

    /**
     * minLimit.
     *
     * @param minLimit the minLimit to set
     */
    public void setMinLimit(Integer minLimit) {
        this.minLimit = minLimit;
    }

    /**
     * payload.
     *
     * @return the payload
     */
    public Integer getPayload() {
        return payload;
    }

    /**
     * payload.
     *
     * @param payload the payload to set
     */
    public void setPayload(Integer payload) {
        this.payload = payload;
    }

    /**
     * status.
     *
     * @return the status
     */
    public Byte getStatus() {
        return status;
    }

    /**
     * status.
     *
     * @param status the status to set
     */
    public void setStatus(Byte status) {
        this.status = status;
    }

    /**
     * gmtCreate.
     *
     * @return the gmtCreate
     */
    public Date getGmtCreate() {
        return gmtCreate;
    }

    /**
     * gmtCreate.
     *
     * @param gmtCreate the gmtCreate to set
     */
    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    /**
     * gmtModified.
     *
     * @return the gmtModified
     */
    public Date getGmtModified() {
        return gmtModified;
    }

    /**
     * gmtModified.
     *
     * @param gmtModified the gmtModified to set
     */
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    /**
     * TODO 简单描述该方法的实现功能（可选）.
     * 
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return "GameCenterResourceLocationEntity [id=" +
                id +
                ", name=" +
                name +
                ", title=" +
                title +
                ", description=" +
                description +
                ", maxLimit=" +
                maxLimit +
                ", minLimit=" +
                minLimit +
                ", payload=" +
                payload +
                ", status=" +
                status +
                ", gmtCreate=" +
                gmtCreate +
                ", gmtModified=" +
                gmtModified +
                "]";
    }

}
